package WebService::Simple::Parser;
use strict;
use warnings;
use base qw(Class::Accessor::Fast);

sub parse_response {}

1;

__END__

=head1 NAME

WebService::Simple::Parser - Base Parser Class

=head1 METHODS

=head2 parse_response($response)

Parses the response object. Your subclass must implement this method

=cut
